require "import"
import "android.widget.*"
import "android.content.Context"
import "android.media.AudioManager"
import "com.androlua.*"

local context = activity or service
local vibrator = context.getSystemService(Context.VIBRATOR_SERVICE)
local audioManager = context.getSystemService(Context.AUDIO_SERVICE)

-- Obtener máximos de volumen
local maxMultimedia = audioManager.getStreamMaxVolume(AudioManager.STREAM_MUSIC)
local maxAccesibilidad = audioManager.getStreamMaxVolume(AudioManager.STREAM_ACCESSIBILITY)

-- Obtener volúmenes actuales
local volMultimedia = audioManager.getStreamVolume(AudioManager.STREAM_MUSIC)
local volAccesibilidad = audioManager.getStreamVolume(AudioManager.STREAM_ACCESSIBILITY)

-- Función para cambiar volumen
function cambiarVolumen(stream, valor)
  audioManager.setStreamVolume(stream, valor, 0)
  vibrator.vibrate(80)
end

-- Layout con SeekBars
local layout = {
  ScrollView,
  layout_width = "match_parent",
  layout_height = "match_parent",
  {
    LinearLayout,
    orientation = "vertical",
    layout_width = "match_parent",
    layout_height = "wrap_content",
    padding = "16dp",
    {
      TextView,
      text = "Control de Volumen Multimedia",
      textSize = "18sp",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      padding = "8dp",
    },
    {
      SeekBar,
      id = "seekMultimedia",
      layout_width = "match_parent",
      layout_height = "wrap_content",
    },
    {
      TextView,
      text = "Control de Volumen de Accesibilidad",
      textSize = "18sp",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      padding = "8dp",
    },
    {
      SeekBar,
      id = "seekAccesibilidad",
      layout_width = "match_parent",
      layout_height = "wrap_content",
    },
    {
      Button,
      text = "Cerrar",
      layout_width = "wrap_content",
      layout_height = "wrap_content",
      layout_gravity = "end",
      layout_marginTop = "16dp",
      onClick = function()
        dlg.dismiss()
      end
    },
  }
}

-- Crear interfaz
dlg = LuaDialog(service)
dlg.View = loadlayout(layout)

-- Configurar SeekBar de volumen multimedia
seekMultimedia.setMax(maxMultimedia)
seekMultimedia.setProgress(volMultimedia)
seekMultimedia.setOnSeekBarChangeListener{
  onProgressChanged = function(view, progress, fromUser)
    if fromUser then
      cambiarVolumen(AudioManager.STREAM_MUSIC, progress)
      service.asyncSpeak("Volumen multimedia: " .. tostring(progress))
    end
  end
}

-- Configurar SeekBar de volumen de accesibilidad
seekAccesibilidad.setMax(maxAccesibilidad)
seekAccesibilidad.setProgress(volAccesibilidad)
seekAccesibilidad.setOnSeekBarChangeListener{
  onProgressChanged = function(view, progress, fromUser)
    if fromUser then
      cambiarVolumen(AudioManager.STREAM_ACCESSIBILITY, progress)
      service.asyncSpeak("Volumen de accesibilidad: " .. tostring(progress))
    end
  end
}

-- Mostrar el diálogo
dlg.show()

return true